/**
 * Title:       job2me data API
 * ClassName:   JobTemplate.java
 * Created:     November 25, 2014
 * Author:      Claudiu Vinte
 * Department:  Economic Informatics, The Bucharest Academy of Economic Studies
 *
 * Description: Implements JobTemplate class for job2me project
 */

package job2me.data.api;

import java.util.Date;
import java.util.LinkedList;
import java.util.List;

public class JobTemplate implements java.io.Serializable{
    protected int ID;
    protected char jobTemplateType;
    protected Enums.JobType jobType;
    protected Enums.JobPeriod jobPeriod;
    protected String startDate;
    protected String endDate;
    protected Enums.NrDailyHours nrHours;
    protected String locality;
    protected String district;
    protected String country;
    protected int nrExperienceYears;
    protected List<Skill> skills;

    public JobTemplate(){}
    public JobTemplate(int ID, Enums.JobType jobType, Enums.JobPeriod jobPeriod, String locality, String district, String country, int nrExperienceYears) {
        this.ID = ID;
        this.jobType = jobType;
        this.jobPeriod = jobPeriod;
        this.locality = locality;
        this.district = district;
        this.country = country;
        this.nrExperienceYears = nrExperienceYears;
    }

    public void setID(int ID) {
        this.ID = ID;
    }

    public void setJobType(Enums.JobType jobType) {
        this.jobType = jobType;
    }

    public char getJobTemplateType() {
        return jobTemplateType;
    }

    public void setJobTemplateType(char jobTemplateType) {
        this.jobTemplateType = jobTemplateType;
    }
    public void setJobPeriod(Enums.JobPeriod jobPeriod) {
        this.jobPeriod = jobPeriod;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public void setNrHours(Enums.NrDailyHours nrHours) {
        this.nrHours = nrHours;
    }

    public void setLocality(String locality) {
        this.locality = locality;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public void setNrExperienceYears(int nrExperienceYears) {
        this.nrExperienceYears = nrExperienceYears;
    }

    public int getID() {
        return ID;
    }

    public Enums.JobType getJobType() {
        return jobType;
    }

    public Enums.JobPeriod getJobPeriod() {
        return jobPeriod;
    }

    public String getStartDate() {
        return startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public Enums.NrDailyHours getNrHours() {
        return nrHours;
    }

    public String getLocality() {
        return locality;
    }

    public String getDistrict() {
        return district;
    }

    public String getCountry() {
        return country;
    }

    public int getNrExperienceYears() {
        return nrExperienceYears;
    }

    public List<Skill> getSkills() {
        return skills;
    }
    
    public void addSkill (Skill s){
        if(skills == null){
            skills = new LinkedList<>();
        }
        skills.add(s);
    }
    
    public void removeSkill (Skill s){
        if(( skills != null ) && ( skills.size() > 0) ){
            skills.remove(s);
        }
    }

    @Override
    public String toString() {
        String nume = jobTemplateType == 'O' ? "Offer " : "Demand ";
        nume += ID+ "," + jobType + "," + jobPeriod + "," + startDate + "," + endDate + "," + nrHours + "," + locality + "," + district + "," + country + "," + nrExperienceYears+",";
        for(Skill s : skills){
            nume+=s.getCategory()+"%"+s.getLabel()+"%"+s.getLevel()+">";
        }
        return nume;
    } 
    
    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Offer other = (Offer) obj;
        if (this.ID != other.getID()) {
            return false;
        }
        return true;
    }
}
